import React from 'react';
import Highlight, { defaultProps } from 'prism-react-renderer';
import { Box } from 'theme-ui';
import { alpha } from '@theme-ui/color';
import { LiveProvider, LivePreview, LiveError, LiveEditor } from 'react-live';

const stripTrailingNewline = str => {
  str = str.trim();

  if (typeof str === 'string' && str[str.length - 1] === '\n') {
    return str.slice(0, -1);
  }

  return str;
};
const parseLanguage = className => {
  return className ? className.replace(/language-/, '') : undefined;
};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

const themes = {
  monochrome: {
    '.comment,.prolog,.doctype,.cdata,.punctuation,.operator,.entity,.url': {
      color: 'secondary'
    },
    '.property,.boolean,.deleted,.class-name,.variable': {
      color: 'primary'
    },
    '.function,.boolean,.number,.constant,.symbol,.class-name': {
      color: 'primary'
    },
    '.atrule, .attr-value, .keyword': {
      color: 'primary'
    },
    '.selector, .string, .char, .inserted': {
      color: 'secondary'
    }
  },
  triadic: {
    '.comment,.prolog,.doctype,.cdata': {
      color: 'secondary'
    },
    '.namespace': {
      opacity: 0.7
    },
    '.string,.attr-value': {
      color: 'yellow'
    },
    '.punctuation,.operator': {
      color: 'primary'
    },
    '.entity,.url,.symbol,.number,.variable,.constant,.property,.regex,.inserted,.class-name': {
      color: 'yellow'
    },
    '.atrule,.keyword,.attr-name,.selector,.boolean': {
      color: 'primary'
    },
    '.function,.deleted,.decorator': {
      color: 'teal'
    },
    '.tag.punctuation': {
      color: 'teal'
    },
    '.function-variable': {
      color: 'teal'
    },
    '.keyword': {
      color: 'red'
    }
  },
  warm: {
    '.comment,.prolog,.doctype,.cdata': {
      color: 'secondary'
    },
    '.namespace': {
      opacity: 0.7
    },
    '.string,.attr-value': {
      color: 'yellow'
    },
    '.punctuation,.operator': {
      color: 'primary'
    },
    '.entity,.url,.symbol,.number,.variable,.constant,.property,.regex,.inserted,.class-name': {
      color: 'yellow'
    },
    '.atrule,.keyword,.attr-name,.selector,.boolean': {
      color: 'primary'
    },
    '.function,.deleted,.decorator': {
      color: 'orange'
    },
    '.tag.punctuation': {
      color: 'orange'
    },
    '.function-variable': {
      color: 'orange'
    },
    '.keyword': {
      color: 'red'
    }
  },
  cool: {
    '.comment,.prolog,.doctype,.cdata': {
      color: 'secondary'
    },
    '.namespace': {
      opacity: 0.7
    },
    '.string,.attr-value': {
      color: 'teal'
    },
    '.punctuation,.operator': {
      color: 'primary'
    },
    '.entity,.url,.symbol,.number,.variable,.constant,.property,.regex,.inserted,.class-name': {
      color: 'teal'
    },
    '.atrule,.keyword,.attr-name,.selector,.boolean': {
      color: 'primary'
    },
    '.function,.deleted,.decorator': {
      color: 'purple'
    },
    '.tag.punctuation': {
      color: 'purple'
    },
    '.function-variable': {
      color: 'purple'
    },
    '.keyword': {
      color: 'blue'
    }
  },
  polychrome: {
    '.comment,.prolog,.doctype,.cdata': {
      color: 'secondary'
    },
    '.namespace': {
      opacity: 0.7
    },
    '.string,.attr-value': {
      color: 'green'
    },
    '.operator,.punctuation': {
      color: 'primary'
    },
    '.entity,.url,.symbol,.number,.variable,.constant,.property,.regex,.inserted,.class-name': {
      color: 'red'
    },
    '.atrule,.keyword,.attr-name,.selector,.boolean': {
      color: 'orange'
    },
    '.function,.deleted,.decorator': {
      color: 'teal'
    },
    '.tag.punctuation': {
      color: 'teal'
    },
    '.function-variable': {
      color: 'teal'
    },
    '.keyword': {
      color: 'purple'
    }
  }
};

const Highlighted = ({
  code,
  language,
  theme
}) => {
  return /*#__PURE__*/React.createElement(Highlight, _extends({}, defaultProps, {
    code: code,
    language: language,
    theme: undefined
  }), ({
    className,
    style,
    tokens,
    getLineProps,
    getTokenProps
  }) => /*#__PURE__*/React.createElement(Box, {
    as: "pre",
    variant: "styles.pre",
    sx: _extends({}, themes[theme], {
      my: [3, 4, 4, 5]
    }),
    className: className
  }, tokens.map((line, i) => /*#__PURE__*/React.createElement("div", _extends({
    key: i
  }, getLineProps({
    line,
    key: i
  })), line.map((token, key) => /*#__PURE__*/React.createElement("span", _extends({
    key: key
  }, getTokenProps({
    token,
    key
  }))))))));
};

const Code = ({
  children,
  className,
  language,
  theme: _theme = 'monochrome'
}) => {
  const code = stripTrailingNewline(children);
  language = language ? language : parseLanguage(className);
  return /*#__PURE__*/React.createElement(Highlighted, {
    code: code,
    language: language,
    theme: _theme
  });
};

const LiveCode = ({
  scope,
  transform,
  children,
  language,
  className,
  live: _live = false,
  theme: _theme = 'monochrome'
}) => {
  const code = stripTrailingNewline(children);
  language = language ? language : parseLanguage(className);

  if (_live) {
    return /*#__PURE__*/React.createElement(LiveProvider, {
      code: code,
      theme: {
        styles: []
      },
      scope: scope,
      transformCode: transform
    }, /*#__PURE__*/React.createElement(Box, {
      sx: {
        my: [3, 4, 4, 5]
      }
    }, /*#__PURE__*/React.createElement(Box, {
      sx: {
        p: [3, 3, 3, 4],
        overflow: 'auto',
        borderColor: 'muted',
        borderStyle: 'solid',
        borderWidth: '1px',
        borderBottomWidth: '0px',
        borderTopLeftRadius: '1px',
        borderTopRightRadius: '1px'
      }
    }, /*#__PURE__*/React.createElement(LivePreview, null), /*#__PURE__*/React.createElement(Box, {
      sx: {
        '#error': {
          p: [3],
          mb: [1],
          mt: [1],
          fontSize: [2],
          bg: alpha('red', 0.2),
          color: 'red',
          overflowWrap: 'break-word',
          wordWrap: 'break-word',
          wordBreak: 'break-word',
          whiteSpace: 'break-spaces'
        }
      }
    }, /*#__PURE__*/React.createElement(LiveError, {
      id: "error"
    }))), /*#__PURE__*/React.createElement(Box, {
      as: "pre",
      variant: "styles.pre",
      sx: _extends({}, themes[_theme], {
        padding: [0, 0, 0, 0],
        '#editor > textarea': {
          '&:focus-visible': {
            outline: 'none'
          },
          '&:focus-visible': {
            outline: 'none !important',
            borderStyle: 'solid !important',
            borderColor: ({
              colors
            }) => `${colors.secondary} !important`,
            borderWidth: '1px !important'
          },
          borderStyle: 'solid !important',
          borderColor: ({
            colors
          }) => `${colors.muted} !important`,
          borderWidth: '1px !important',
          padding: '16px !important',
          borderBottomLeftRadius: '1px',
          borderBottomRightRadius: '1px',
          '@media screen and (min-width: 40em)': {
            padding: '16px !important'
          },
          '@media screen and (min-width: 64em)': {
            padding: '16px !important'
          },
          '@media screen and (min-width: 102em)': {
            padding: '24px !important'
          }
        },
        '#editor > pre': {
          padding: '16px !important',
          '@media screen and (min-width: 40em)': {
            padding: '16px !important'
          },
          '@media screen and (min-width: 64em)': {
            padding: '16px !important'
          },
          '@media screen and (min-width: 102em)': {
            padding: '24px !important'
          }
        }
      })
    }, /*#__PURE__*/React.createElement(LiveEditor, {
      id: "editor",
      textareaId: "text-area"
    }))));
  }

  return /*#__PURE__*/React.createElement(Highlighted, {
    code: code,
    language: language,
    theme: _theme
  });
};

const Pre = ({
  children
}) => {
  return /*#__PURE__*/React.createElement(React.Fragment, null, children);
};

export { Code, LiveCode, Pre, themes };
//# sourceMappingURL=index.modern.js.map
